enum one { liner };

enum not {

a, one,

liner };

enum foo { bar, baz, quux };

/*
 * In some tests, the following line remains longer than 80
 * characters. Perhaps a bug?
*/
enum longer_enum_that { will, not, all, fit, on, one, line, as, longg, as, the, cutoff, is, reasonable, because, this, is, a, very, very, wide, line };

enum q { w,
e,r,
t,


y


}


;